You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/02 12:25:26 UTC

svn commit: r1209415 [12/19] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mai...

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/Struts1Action.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/Struts1Action.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/Struts1Action.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/Struts1Action.java Fri Dec  2 11:24:48 2011
@@ -39,12 +39,12 @@ import org.apache.struts2.StrutsExceptio
 import org.apache.struts2.dispatcher.DefaultActionSupport;
 import org.apache.struts2.dispatcher.Dispatcher;
 
-import org.apache.struts2.xwork2.ActionContext;
-import org.apache.struts2.xwork2.ObjectFactory;
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.inject.Inject;
-import org.apache.struts2.xwork2.interceptor.ScopedModelDriven;
+import com.opensymphony.xwork2.ActionContext;
+import com.opensymphony.xwork2.ObjectFactory;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.inject.Inject;
+import com.opensymphony.xwork2.interceptor.ScopedModelDriven;
 
 /**
  * Wraps legacy Struts 1.3 Actions.  Supports the following features:

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/Struts1Factory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/Struts1Factory.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/Struts1Factory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/Struts1Factory.java Fri Dec  2 11:24:48 2011
@@ -21,17 +21,21 @@
 
 package org.apache.struts2.s1;
 
-import org.apache.struts2.xwork2.*;
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
-import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
+import com.opensymphony.xwork2.*;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
 
+import org.apache.struts.Globals;
 import org.apache.struts.action.*;
 import org.apache.struts.config.*;
 
 import java.util.Iterator;
 import java.util.Arrays;
+import java.util.Map;
+
+import javax.servlet.ServletContext;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperActionForward.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperActionForward.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperActionForward.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperActionForward.java Fri Dec  2 11:24:48 2011
@@ -22,7 +22,7 @@
 package org.apache.struts2.s1;
 
 import org.apache.struts.action.ActionForward;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
 
 /**
  * Wrapper for a Struts 1.x ActionForward based on an XWork ResultConfig.  Using a wrapper object

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperActionMapping.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperActionMapping.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperActionMapping.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperActionMapping.java Fri Dec  2 11:24:48 2011
@@ -26,9 +26,9 @@ import org.apache.struts.action.ActionFo
 import org.apache.struts.config.ModuleConfig;
 import org.apache.struts.config.ExceptionConfig;
 import org.apache.struts.config.ForwardConfig;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
-import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
 
 import java.util.Iterator;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperExceptionConfig.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperExceptionConfig.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperExceptionConfig.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperExceptionConfig.java Fri Dec  2 11:24:48 2011
@@ -21,7 +21,7 @@
 
 package org.apache.struts2.s1;
 
-import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
+import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
 import org.apache.struts.config.ExceptionConfig;
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperMessageResources.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperMessageResources.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperMessageResources.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperMessageResources.java Fri Dec  2 11:24:48 2011
@@ -25,7 +25,7 @@ import java.util.Locale;
 
 import org.apache.struts.util.MessageResources;
 
-import org.apache.struts2.xwork2.TextProvider;
+import com.opensymphony.xwork2.TextProvider;
 
 /**
  * Wraps the Struts 1 message resources, delegating to Struts 2 resources

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperModuleConfig.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperModuleConfig.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperModuleConfig.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/main/java/org/apache/struts2/s1/WrapperModuleConfig.java Fri Dec  2 11:24:48 2011
@@ -34,9 +34,9 @@ import org.apache.struts.config.MessageR
 import org.apache.struts.config.ModuleConfig;
 import org.apache.struts.config.PlugInConfig;
 
-import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
 
 /**
  * Wrapper for a Struts 1.x ModuleConfig based on an XWork PackageConfig.  Using a wrapper object
@@ -65,8 +65,8 @@ class WrapperModuleConfig implements Mod
             for (Iterator i = delegate.getActionConfigs().entrySet().iterator(); i.hasNext();) {
                 Map.Entry entry = (Map.Entry) i.next();
                 String actionPath = '/' + (String) entry.getKey();
-                org.apache.struts2.xwork2.config.entities.ActionConfig actionConfig =
-                        (org.apache.struts2.xwork2.config.entities.ActionConfig) entry.getValue();
+                com.opensymphony.xwork2.config.entities.ActionConfig actionConfig =
+                        (com.opensymphony.xwork2.config.entities.ActionConfig) entry.getValue();
                 _actionMappings.put(actionPath, strutsFactory.createActionMapping(actionConfig, actionPath, this));
             }
         }

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/test/java/org/apache/struts2/s1/Struts1FactoryTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/test/java/org/apache/struts2/s1/Struts1FactoryTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/test/java/org/apache/struts2/s1/Struts1FactoryTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/test/java/org/apache/struts2/s1/Struts1FactoryTest.java Fri Dec  2 11:24:48 2011
@@ -23,6 +23,8 @@ package org.apache.struts2.s1;
 
 import java.lang.reflect.InvocationTargetException;
 
+import junit.framework.TestCase;
+
 import org.apache.struts.action.ActionErrors;
 import org.apache.struts.action.ActionForward;
 import org.apache.struts.action.ActionMapping;
@@ -34,10 +36,14 @@ import org.apache.struts.config.ModuleCo
 import org.apache.struts2.StrutsTestCase;
 import org.apache.struts2.config.StrutsXmlConfigurationProvider;
 
-import org.apache.struts2.xwork2.ActionSupport;
-import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.ActionSupport;
+import com.opensymphony.xwork2.ObjectFactory;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.ConfigurationManager;
+import com.opensymphony.xwork2.config.ConfigurationProvider;
+import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
 
 /**
  * Test of Struts1Factory, which creates Struts 1.x wrappers around XWork config objects.
@@ -108,8 +114,8 @@ public class Struts1FactoryTest extends 
      */
     public void testCreateActionMapping() {
         PackageConfig packageConfig = configuration.getPackageConfig(PACKAGE_NAME);
-        org.apache.struts2.xwork2.config.entities.ActionConfig actionConfig =
-                (org.apache.struts2.xwork2.config.entities.ActionConfig) packageConfig.getActionConfigs().get("action1");
+        com.opensymphony.xwork2.config.entities.ActionConfig actionConfig =
+                (com.opensymphony.xwork2.config.entities.ActionConfig) packageConfig.getActionConfigs().get("action1");
         ActionMapping mapping = factory.createActionMapping(actionConfig);
         assertNotNull(mapping);
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/test/resources/org/apache/struts2/s1/test-struts-factory.xml
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/test/resources/org/apache/struts2/s1/test-struts-factory.xml?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/test/resources/org/apache/struts2/s1/test-struts-factory.xml (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/struts1/src/test/resources/org/apache/struts2/s1/test-struts-factory.xml Fri Dec  2 11:24:48 2011
@@ -27,8 +27,8 @@
         
 <!-- Used by the TestStrutsFactory TestCase. -->
 <struts>
-    <bean class="org.apache.struts2.xwork2.ObjectFactory" name="default" />
-	<bean type="org.apache.struts2.xwork2.ActionProxyFactory" name="default" class="org.apache.struts2.xwork2.DefaultActionProxyFactory"/>
+    <bean class="com.opensymphony.xwork2.ObjectFactory" name="default" />
+	<bean type="com.opensymphony.xwork2.ActionProxyFactory" name="default" class="com.opensymphony.xwork2.DefaultActionProxyFactory"/>
 	<constant name="devMode" value="false" />
   <package name="org/apache/struts2/s1" namespace="/org/apache/struts2/s1">
     <result-types>
@@ -45,7 +45,7 @@
         exception="java.lang.Exception"
         result="globalResult"/>
     </global-exception-mappings>
-    <action class="org.apache.struts2.xwork2.ActionSupport" name="action1">
+    <action class="com.opensymphony.xwork2.ActionSupport" name="action1">
       <result name="result1" type="servletDispatcherResult">
         <param name="location">result1.jsp</param>
       </result>
@@ -61,7 +61,7 @@
         exception="java.lang.IllegalStateException"
         result="anotherResult"/>
     </action>
-    <action class="org.apache.struts2.xwork2.ActionSupport" name="action2"/>
+    <action class="com.opensymphony.xwork2.ActionSupport" name="action2"/>
   </package>
 </struts>
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/testng/src/main/java/org/apache/struts2/StrutsTestCase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/testng/src/main/java/org/apache/struts2/StrutsTestCase.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/testng/src/main/java/org/apache/struts2/StrutsTestCase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/testng/src/main/java/org/apache/struts2/StrutsTestCase.java Fri Dec  2 11:24:48 2011
@@ -29,7 +29,7 @@ import org.testng.annotations.AfterTest;
 import org.testng.annotations.BeforeTest;
 import org.springframework.mock.web.MockServletContext;
 
-import org.apache.struts2.xwork2.TestNGXWorkTestCase;
+import com.opensymphony.xwork2.TestNGXWorkTestCase;
 
 /**
  * Base test class for TestNG unit tests.  Provides common Struts variables

Modified: struts/struts2/branches/STRUTS_3_X/plugins/testng/src/test/java/org/apache/struts2/TestNGStrutsTestCaseTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/testng/src/test/java/org/apache/struts2/TestNGStrutsTestCaseTest.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/testng/src/test/java/org/apache/struts2/TestNGStrutsTestCaseTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/testng/src/test/java/org/apache/struts2/TestNGStrutsTestCaseTest.java Fri Dec  2 11:24:48 2011
@@ -28,7 +28,7 @@ import org.testng.TestListenerAdapter;
 import org.testng.TestNG;
 import org.testng.annotations.Test;
 
-import org.apache.struts2.xwork2.config.ConfigurationManager;
+import com.opensymphony.xwork2.config.ConfigurationManager;
 
 public class TestNGStrutsTestCaseTest extends TestCase {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/tiles/StrutsTilesListener.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/tiles/StrutsTilesListener.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/tiles/StrutsTilesListener.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/tiles/StrutsTilesListener.java Fri Dec  2 11:24:48 2011
@@ -31,8 +31,8 @@ import org.apache.tiles.TilesException;
 import org.apache.tiles.factory.TilesContainerFactory;
 import org.apache.tiles.web.startup.TilesListener;
 
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 /**
  * Listener used to automatically inject ServletContext

Modified: struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/tiles/StrutsTilesRequestContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/tiles/StrutsTilesRequestContext.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/tiles/StrutsTilesRequestContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/tiles/StrutsTilesRequestContext.java Fri Dec  2 11:24:48 2011
@@ -31,11 +31,11 @@ import org.apache.struts2.views.freemark
 import org.apache.tiles.context.TilesRequestContext;
 import org.apache.tiles.context.TilesRequestContextWrapper;
 
-import org.apache.struts2.xwork2.ActionContext;
-import org.apache.struts2.xwork2.ActionInvocation;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.ActionContext;
+import com.opensymphony.xwork2.ActionInvocation;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 /**
  * Default implementation of TilesUtil.

Modified: struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/views/tiles/TilesResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/views/tiles/TilesResult.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/views/tiles/TilesResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/tiles/src/main/java/org/apache/struts2/views/tiles/TilesResult.java Fri Dec  2 11:24:48 2011
@@ -30,7 +30,7 @@ import org.apache.struts2.dispatcher.Ser
 import org.apache.tiles.TilesContainer;
 import org.apache.tiles.access.TilesAccess;
 
-import org.apache.struts2.xwork2.ActionInvocation;
+import com.opensymphony.xwork2.ActionInvocation;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/pom.xml
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/pom.xml?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/pom.xml (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/pom.xml Fri Dec  2 11:24:48 2011
@@ -154,7 +154,7 @@
                 <artifactId>maven-bundle-plugin</artifactId>
                 <configuration>
                     <instructions>
-                        <Export-Package>org.apache.struts2.xwork2.*</Export-Package>
+                        <Export-Package>com.opensymphony.xwork2.*</Export-Package>
                     </instructions>
                 </configuration>
                 <executions>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/CompositeTextProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/CompositeTextProvider.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionInvocation.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionInvocation.java Fri Dec  2 11:24:48 2011
@@ -13,21 +13,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.ConfigurationException;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.inject.Inject;
-import org.apache.struts2.xwork2.interceptor.PreResultListener;
-import org.apache.struts2.xwork2.util.ValueStack;
-import org.apache.struts2.xwork2.util.ValueStackFactory;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
-import org.apache.struts2.xwork2.util.profiling.UtilTimerStack;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.ConfigurationException;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.InterceptorMapping;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.inject.Inject;
+import com.opensymphony.xwork2.interceptor.PreResultListener;
+import com.opensymphony.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStackFactory;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.profiling.UtilTimerStack;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
@@ -43,7 +43,7 @@ import java.util.Map;
  * @author Rainer Hermanns
  * @author tmjee
  * @version $Date$ $Id$
- * @see org.apache.struts2.xwork2.DefaultActionProxy
+ * @see com.opensymphony.xwork2.DefaultActionProxy
  */
 public class DefaultActionInvocation implements ActionInvocation {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionProxy.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionProxy.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionProxy.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionProxy.java Fri Dec  2 11:24:48 2011
@@ -18,16 +18,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.ConfigurationException;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.inject.Inject;
-import org.apache.struts2.xwork2.util.LocalizedTextUtil;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
-import org.apache.struts2.xwork2.util.profiling.UtilTimerStack;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.ConfigurationException;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.inject.Inject;
+import com.opensymphony.xwork2.util.LocalizedTextUtil;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.profiling.UtilTimerStack;
 import org.apache.commons.lang.StringEscapeUtils;
 import org.apache.commons.lang.StringUtils;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionProxyFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionProxyFactory.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultTextProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultTextProvider.java Fri Dec  2 11:24:48 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.util.LocalizedTextUtil;
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.LocalizedTextUtil;
+import com.opensymphony.xwork2.util.ValueStack;
 
 import java.io.Serializable;
 import java.text.MessageFormat;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultUnknownHandlerManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultUnknownHandlerManager.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultUnknownHandlerManager.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultUnknownHandlerManager.java Fri Dec  2 11:24:48 2011
@@ -13,22 +13,26 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Set;
 
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.config.entities.UnknownHandlerConfig;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.inject.Inject;
+import com.opensymphony.xwork2.ActionContext;
+import com.opensymphony.xwork2.Result;
+import com.opensymphony.xwork2.UnknownHandler;
+import com.opensymphony.xwork2.UnknownHandlerManager;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.UnknownHandlerConfig;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.inject.Inject;
 
 /**
  * Default implementation of UnknownHandlerManager
  *
- * @see org.apache.struts2.xwork2.UnknownHandlerManager
+ * @see com.opensymphony.xwork2.UnknownHandlerManager
  */
 public class DefaultUnknownHandlerManager implements UnknownHandlerManager {
     protected ArrayList<UnknownHandler> unknownHandlers;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/InvalidMetadataException.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/InvalidMetadataException.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/InvalidMetadataException.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/InvalidMetadataException.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 /**
  * <code>InvalidMetadataException</code>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/LocaleProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/LocaleProvider.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/LocaleProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/LocaleProvider.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 import java.util.Locale;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/MockActionInvocation.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/MockActionInvocation.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/MockActionInvocation.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/MockActionInvocation.java Fri Dec  2 11:24:48 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 /**
  * Mock for an {@link ActionInvocation}.
@@ -22,5 +22,5 @@ package org.apache.struts2.xwork2;
  * @author plightbo
  * @deprecated Please use @see com.opensymphony.xwork2.mock.MockActionInvocation instead
  */
-@Deprecated public class MockActionInvocation extends org.apache.struts2.xwork2.mock.MockActionInvocation {
+@Deprecated public class MockActionInvocation extends com.opensymphony.xwork2.mock.MockActionInvocation {
 }

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ModelDriven.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ModelDriven.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ModelDriven.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ModelDriven.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ObjectFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ObjectFactory.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ObjectFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ObjectFactory.java Fri Dec  2 11:24:48 2011
@@ -13,22 +13,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.ConfigurationException;
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
-import org.apache.struts2.xwork2.config.entities.InterceptorConfig;
-import org.apache.struts2.xwork2.config.entities.ResultConfig;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.inject.Inject;
-import org.apache.struts2.xwork2.interceptor.Interceptor;
-import org.apache.struts2.xwork2.util.ClassLoaderUtil;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
-import org.apache.struts2.xwork2.util.reflection.ReflectionException;
-import org.apache.struts2.xwork2.util.reflection.ReflectionExceptionHandler;
-import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
-import org.apache.struts2.xwork2.validator.Validator;
+import com.opensymphony.xwork2.config.ConfigurationException;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.InterceptorConfig;
+import com.opensymphony.xwork2.config.entities.ResultConfig;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.inject.Inject;
+import com.opensymphony.xwork2.interceptor.Interceptor;
+import com.opensymphony.xwork2.util.ClassLoaderUtil;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.reflection.ReflectionException;
+import com.opensymphony.xwork2.util.reflection.ReflectionExceptionHandler;
+import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import com.opensymphony.xwork2.validator.Validator;
 
 import java.io.Serializable;
 import java.util.HashMap;
@@ -112,7 +112,7 @@ public class ObjectFactory implements Se
      * @param actionName the name the action configuration is set up with in the configuration
      * @param namespace the namespace the action is configured in
      * @param config the action configuration found in the config for the actionName / namespace
-     * @param extraContext a Map of extra context which uses the same keys as the {@link org.apache.struts2.xwork2.ActionContext}
+     * @param extraContext a Map of extra context which uses the same keys as the {@link com.opensymphony.xwork2.ActionContext}
      * @return instance of the action class to handle a web request
      * @throws Exception
      */
@@ -124,7 +124,7 @@ public class ObjectFactory implements Se
      * Build a generic Java object of the given type.
      *
      * @param clazz the type of Object to build
-     * @param extraContext a Map of extra context which uses the same keys as the {@link org.apache.struts2.xwork2.ActionContext}
+     * @param extraContext a Map of extra context which uses the same keys as the {@link com.opensymphony.xwork2.ActionContext}
      */
     public Object buildBean(Class clazz, Map<String, Object> extraContext) throws Exception {
         return clazz.newInstance();
@@ -144,7 +144,7 @@ public class ObjectFactory implements Se
      * Build a generic Java object of the given type.
      *
      * @param className the type of Object to build
-     * @param extraContext a Map of extra context which uses the same keys as the {@link org.apache.struts2.xwork2.ActionContext}
+     * @param extraContext a Map of extra context which uses the same keys as the {@link com.opensymphony.xwork2.ActionContext}
      */
     public Object buildBean(String className, Map<String, Object> extraContext) throws Exception {
         return buildBean(className, extraContext, true);
@@ -154,7 +154,7 @@ public class ObjectFactory implements Se
      * Build a generic Java object of the given type.
      *
      * @param className the type of Object to build
-     * @param extraContext a Map of extra context which uses the same keys as the {@link org.apache.struts2.xwork2.ActionContext}
+     * @param extraContext a Map of extra context which uses the same keys as the {@link com.opensymphony.xwork2.ActionContext}
      */
     public Object buildBean(String className, Map<String, Object> extraContext, boolean injectInternal) throws Exception {
         Class clazz = getClassInstance(className);
@@ -217,7 +217,7 @@ public class ObjectFactory implements Se
      * Build a Result using the type in the ResultConfig and set the parameters in the ResultConfig.
      *
      * @param resultConfig the ResultConfig found for the action with the result code returned
-     * @param extraContext a Map of extra context which uses the same keys as the {@link org.apache.struts2.xwork2.ActionContext}
+     * @param extraContext a Map of extra context which uses the same keys as the {@link com.opensymphony.xwork2.ActionContext}
      */
     public Result buildResult(ResultConfig resultConfig, Map<String, Object> extraContext) throws Exception {
         String resultClassName = resultConfig.getClassName();
@@ -247,7 +247,7 @@ public class ObjectFactory implements Se
      *
      * @param className the type of Validator to build
      * @param params    property name -> value Map to set onto the Validator instance
-     * @param extraContext a Map of extra context which uses the same keys as the {@link org.apache.struts2.xwork2.ActionContext}
+     * @param extraContext a Map of extra context which uses the same keys as the {@link com.opensymphony.xwork2.ActionContext}
      */
     public Validator buildValidator(String className, Map<String, String> params, Map<String, Object> extraContext) throws Exception {
         Validator validator = (Validator) buildBean(className, null);

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Preparable.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Preparable.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Preparable.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Preparable.java Fri Dec  2 11:24:48 2011
@@ -13,15 +13,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 
 /**
- * Preparable Actions will have their <code>prepare()</code> method called if the {@link org.apache.struts2.xwork2.interceptor.PrepareInterceptor}
+ * Preparable Actions will have their <code>prepare()</code> method called if the {@link com.opensymphony.xwork2.interceptor.PrepareInterceptor}
  * is applied to the ActionConfig.
  *
  * @author Jason Carreira
- * @see org.apache.struts2.xwork2.interceptor.PrepareInterceptor
+ * @see com.opensymphony.xwork2.interceptor.PrepareInterceptor
  */
 public interface Preparable {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ResourceBundleTextProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ResourceBundleTextProvider.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ResourceBundleTextProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ResourceBundleTextProvider.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 import java.util.ResourceBundle;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Result.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Result.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Result.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Result.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 import java.io.Serializable;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TestNGXWorkTestCase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TestNGXWorkTestCase.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TestNGXWorkTestCase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TestNGXWorkTestCase.java Fri Dec  2 11:24:48 2011
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.ConfigurationManager;
-import org.apache.struts2.xwork2.config.ConfigurationProvider;
-import org.apache.struts2.xwork2.config.impl.MockConfiguration;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.util.XWorkTestCaseHelper;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.ConfigurationManager;
+import com.opensymphony.xwork2.config.ConfigurationProvider;
+import com.opensymphony.xwork2.config.impl.MockConfiguration;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.util.XWorkTestCaseHelper;
 import org.testng.annotations.AfterTest;
 import org.testng.annotations.BeforeTest;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProvider.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProviderFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProviderFactory.java Fri Dec  2 11:24:48 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.inject.Inject;
+import com.opensymphony.xwork2.inject.Inject;
 
 import java.util.ResourceBundle;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProviderSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProviderSupport.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProviderSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProviderSupport.java Fri Dec  2 11:24:48 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.util.LocalizedTextUtil;
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.LocalizedTextUtil;
+import com.opensymphony.xwork2.util.ValueStack;
 
 import java.util.*;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Unchainable.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Unchainable.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Unchainable.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Unchainable.java Fri Dec  2 11:24:48 2011
@@ -14,12 +14,12 @@
  * limitations under the License.
  */
 
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 /**
  * Simple marker interface to indicate an object should <b>not</b> have its properties copied during chaining.
  *
- * @see org.apache.struts2.xwork2.interceptor.ChainingInterceptor
+ * @see com.opensymphony.xwork2.interceptor.ChainingInterceptor
  */
 public interface Unchainable {
 }

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/UnknownHandler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/UnknownHandler.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/UnknownHandler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/UnknownHandler.java Fri Dec  2 11:24:48 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
 
 /**
  * Handles cases when the result or action is unknown.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/UnknownHandlerManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/UnknownHandlerManager.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/UnknownHandlerManager.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/UnknownHandlerManager.java Fri Dec  2 11:24:48 2011
@@ -13,16 +13,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
 
 import java.util.List;
 
 /**
  * An unknown handler manager contains a list of UnknownHandler and iterates on them by order
  *
- * @see org.apache.struts2.xwork2.DefaultUnknownHandlerManager
+ * @see com.opensymphony.xwork2.DefaultUnknownHandlerManager
  */
 public interface UnknownHandlerManager {
     Result handleUnknownResult(ActionContext actionContext, String actionName, ActionConfig actionConfig, String resultCode);

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Validateable.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Validateable.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Validateable.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/Validateable.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 
 /**
@@ -21,7 +21,7 @@ package org.apache.struts2.xwork2;
  *
  * @author Jason Carreira
  * @see ActionSupport
- * @see org.apache.struts2.xwork2.interceptor.DefaultWorkflowInterceptor
+ * @see com.opensymphony.xwork2.interceptor.DefaultWorkflowInterceptor
  */
 public interface Validateable {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ValidationAware.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ValidationAware.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ValidationAware.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ValidationAware.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 import java.util.Collection;
 import java.util.List;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ValidationAwareSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ValidationAwareSupport.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ValidationAwareSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ValidationAwareSupport.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 import java.io.Serializable;
 import java.util.*;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWork.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWork.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWork.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWork.java Fri Dec  2 11:24:48 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.ConfigurationManager;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.ConfigurationManager;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 import java.util.Collections;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkException.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkException.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkException.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkException.java Fri Dec  2 11:24:48 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.util.location.Locatable;
-import org.apache.struts2.xwork2.util.location.Location;
-import org.apache.struts2.xwork2.util.location.LocationUtils;
+import com.opensymphony.xwork2.util.location.Locatable;
+import com.opensymphony.xwork2.util.location.Location;
+import com.opensymphony.xwork2.util.location.LocationUtils;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkJUnit4TestCase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkJUnit4TestCase.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkJUnit4TestCase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkJUnit4TestCase.java Fri Dec  2 11:24:48 2011
@@ -1,17 +1,17 @@
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.ConfigurationException;
-import org.apache.struts2.xwork2.config.ConfigurationManager;
-import org.apache.struts2.xwork2.config.ConfigurationProvider;
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.inject.ContainerBuilder;
-import org.apache.struts2.xwork2.inject.Context;
-import org.apache.struts2.xwork2.inject.Factory;
-import org.apache.struts2.xwork2.inject.Scope;
-import org.apache.struts2.xwork2.test.StubConfigurationProvider;
-import org.apache.struts2.xwork2.util.XWorkTestCaseHelper;
-import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.ConfigurationException;
+import com.opensymphony.xwork2.config.ConfigurationManager;
+import com.opensymphony.xwork2.config.ConfigurationProvider;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.inject.ContainerBuilder;
+import com.opensymphony.xwork2.inject.Context;
+import com.opensymphony.xwork2.inject.Factory;
+import com.opensymphony.xwork2.inject.Scope;
+import com.opensymphony.xwork2.test.StubConfigurationProvider;
+import com.opensymphony.xwork2.util.XWorkTestCaseHelper;
+import com.opensymphony.xwork2.util.location.LocatableProperties;
 import org.junit.After;
 import org.junit.Before;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkMessages.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkMessages.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkMessages.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkMessages.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkTestCase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkTestCase.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkTestCase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/XWorkTestCase.java Fri Dec  2 11:24:48 2011
@@ -14,16 +14,16 @@
  * limitations under the License.
  */
 
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.config.Configuration;
-import org.apache.struts2.xwork2.config.ConfigurationException;
-import org.apache.struts2.xwork2.config.ConfigurationManager;
-import org.apache.struts2.xwork2.config.ConfigurationProvider;
-import org.apache.struts2.xwork2.inject.*;
-import org.apache.struts2.xwork2.test.StubConfigurationProvider;
-import org.apache.struts2.xwork2.util.XWorkTestCaseHelper;
-import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import com.opensymphony.xwork2.config.Configuration;
+import com.opensymphony.xwork2.config.ConfigurationException;
+import com.opensymphony.xwork2.config.ConfigurationManager;
+import com.opensymphony.xwork2.config.ConfigurationProvider;
+import com.opensymphony.xwork2.inject.*;
+import com.opensymphony.xwork2.test.StubConfigurationProvider;
+import com.opensymphony.xwork2.util.XWorkTestCaseHelper;
+import com.opensymphony.xwork2.util.location.LocatableProperties;
 import junit.framework.TestCase;
 
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/Configuration.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/Configuration.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/Configuration.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/Configuration.java Fri Dec  2 11:24:48 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.config.entities.UnknownHandlerConfig;
-import org.apache.struts2.xwork2.inject.Container;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.config.entities.UnknownHandlerConfig;
+import com.opensymphony.xwork2.inject.Container;
 
 import java.io.Serializable;
 import java.util.List;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationException.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationException.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationException.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationException.java Fri Dec  2 11:24:48 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
-import org.apache.struts2.xwork2.XWorkException;
+import com.opensymphony.xwork2.XWorkException;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationManager.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationManager.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationManager.java Fri Dec  2 11:24:48 2011
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
-import org.apache.struts2.xwork2.config.impl.DefaultConfiguration;
-import org.apache.struts2.xwork2.config.providers.XWorkConfigurationProvider;
-import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
-import org.apache.struts2.xwork2.util.FileManager;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.config.impl.DefaultConfiguration;
+import com.opensymphony.xwork2.config.providers.XWorkConfigurationProvider;
+import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
+import com.opensymphony.xwork2.util.FileManager;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -57,7 +57,7 @@ public class ConfigurationManager {
     /**
      * Get the current XWork configuration object.  By default an instance of DefaultConfiguration will be returned
      *
-     * @see org.apache.struts2.xwork2.config.impl.DefaultConfiguration
+     * @see com.opensymphony.xwork2.config.impl.DefaultConfiguration
      */
     public synchronized Configuration getConfiguration() {
         if (configuration == null) {
@@ -186,7 +186,7 @@ public class ConfigurationManager {
      * clears the registered ConfigurationProviders.  this method will call destroy() on each of the registered
      * ConfigurationProviders
      *
-     * @see org.apache.struts2.xwork2.config.ConfigurationProvider#destroy
+     * @see com.opensymphony.xwork2.config.ConfigurationProvider#destroy
      * @deprecated Since 2.1, use {@link #clearContainerProviders()}
      */
     @Deprecated public void clearConfigurationProviders() {

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationProvider.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationProvider.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
 /**
  * Interface to be implemented by all forms of XWork configuration classes.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationUtil.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ConfigurationUtil.java Fri Dec  2 11:24:48 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
-import org.apache.struts2.xwork2.config.entities.PackageConfig;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.config.entities.PackageConfig;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 import java.util.ArrayList;
 import java.util.Collections;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ContainerProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ContainerProvider.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ContainerProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ContainerProvider.java Fri Dec  2 11:24:48 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
-import org.apache.struts2.xwork2.inject.ContainerBuilder;
-import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import com.opensymphony.xwork2.inject.ContainerBuilder;
+import com.opensymphony.xwork2.util.location.LocatableProperties;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/PackageProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/PackageProvider.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/PackageProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/PackageProvider.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
 /**
  * Provides configuration packages.  The separate init and loadPackages calls are due to the need to 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ReferenceResolverException.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ReferenceResolverException.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ReferenceResolverException.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/ReferenceResolverException.java Fri Dec  2 11:24:48 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
-import org.apache.struts2.xwork2.XWorkException;
+import com.opensymphony.xwork2.XWorkException;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/RuntimeConfiguration.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/RuntimeConfiguration.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/RuntimeConfiguration.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/RuntimeConfiguration.java Fri Dec  2 11:24:48 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config;
+package com.opensymphony.xwork2.config;
 
-import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import com.opensymphony.xwork2.config.entities.ActionConfig;
 
 import java.io.Serializable;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/ExceptionMappingConfig.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/ExceptionMappingConfig.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/ExceptionMappingConfig.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/ExceptionMappingConfig.java Fri Dec  2 11:24:48 2011
@@ -14,10 +14,10 @@
  * limitations under the License.
  */
 
-package org.apache.struts2.xwork2.config.entities;
+package com.opensymphony.xwork2.config.entities;
 
-import org.apache.struts2.xwork2.util.location.Located;
-import org.apache.struts2.xwork2.util.location.Location;
+import com.opensymphony.xwork2.util.location.Located;
+import com.opensymphony.xwork2.util.location.Location;
 
 import java.io.Serializable;
 import java.util.Collections;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorConfig.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorConfig.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorConfig.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorConfig.java Fri Dec  2 11:24:48 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config.entities;
+package com.opensymphony.xwork2.config.entities;
 
-import org.apache.struts2.xwork2.util.location.Located;
-import org.apache.struts2.xwork2.util.location.Location;
+import com.opensymphony.xwork2.util.location.Located;
+import com.opensymphony.xwork2.util.location.Location;
 
 import java.io.Serializable;
 import java.util.Collections;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorListHolder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorListHolder.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorListHolder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorListHolder.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config.entities;
+package com.opensymphony.xwork2.config.entities;
 
 import java.util.List;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorLocator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorLocator.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorLocator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorLocator.java Fri Dec  2 11:24:48 2011
@@ -1,4 +1,4 @@
-package org.apache.struts2.xwork2.config.entities;
+package com.opensymphony.xwork2.config.entities;
 
 /**
  * Defines an object that can be used to retrieve interceptor configuration

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorMapping.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorMapping.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorMapping.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorMapping.java Fri Dec  2 11:24:48 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package org.apache.struts2.xwork2.config.entities;
+package com.opensymphony.xwork2.config.entities;
 
-import org.apache.struts2.xwork2.interceptor.Interceptor;
+import com.opensymphony.xwork2.interceptor.Interceptor;
 
 import java.io.Serializable;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorStackConfig.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorStackConfig.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorStackConfig.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/InterceptorStackConfig.java Fri Dec  2 11:24:48 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config.entities;
+package com.opensymphony.xwork2.config.entities;
 
-import org.apache.struts2.xwork2.util.location.Located;
-import org.apache.struts2.xwork2.util.location.Location;
+import com.opensymphony.xwork2.util.location.Located;
+import com.opensymphony.xwork2.util.location.Location;
 
 import java.io.Serializable;
 import java.util.ArrayList;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/PackageConfig.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/PackageConfig.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/PackageConfig.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/PackageConfig.java Fri Dec  2 11:24:48 2011
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config.entities;
+package com.opensymphony.xwork2.config.entities;
 
-import org.apache.struts2.xwork2.util.location.Located;
-import org.apache.struts2.xwork2.util.location.Location;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.location.Located;
+import com.opensymphony.xwork2.util.location.Location;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 import java.io.Serializable;
 import java.util.*;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/Parameterizable.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/Parameterizable.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/CompositeTextProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/CompositeTextProvider.java Fri Dec  2 11:24:48 2011
@@ -1,8 +1,8 @@
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.util.ValueStack;
-import org.apache.struts2.xwork2.util.logging.Logger;
-import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import com.opensymphony.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
 
 import java.util.*;
 
@@ -42,7 +42,7 @@ public class CompositeTextProvider imple
     /**
      * @param key The key to lookup in ressource bundles.
      * @return <tt>true</tt>, if the requested key is found in one of the ressource bundles.
-     * @see {@link org.apache.struts2.xwork2.TextProvider#hasKey(String)}
+     * @see {@link com.opensymphony.xwork2.TextProvider#hasKey(String)}
      *      It will consult each individual {@link TextProvider}s and return true if either one of the
      *      {@link TextProvider} has such a <code>key></code> else false.
      */
@@ -62,7 +62,7 @@ public class CompositeTextProvider imple
      *
      * @param key The key to lookup in ressource bundles.
      * @return The i18n text for the requested key.
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText(String)}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText(String)}
      */
     public String getText(String key) {
         return getText(key, key, Collections.emptyList());
@@ -75,7 +75,7 @@ public class CompositeTextProvider imple
      * @param key
      * @param defaultValue
      * @return
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText(String, String)}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText(String, String)}
      */
     public String getText(String key, String defaultValue) {
         return getText(key, defaultValue, Collections.emptyList());
@@ -90,7 +90,7 @@ public class CompositeTextProvider imple
      * @param defaultValue
      * @param obj
      * @return
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText(String, String, String)}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText(String, String, String)}
      */
     public String getText(String key, String defaultValue, final String obj) {
         return getText(key, defaultValue, new ArrayList<Object>() {
@@ -109,7 +109,7 @@ public class CompositeTextProvider imple
      * @param key
      * @param args
      * @return
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText(String, java.util.List)}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText(String, java.util.List)}
      */
     public String getText(String key, List<?> args) {
         return getText(key, key, args);
@@ -122,7 +122,7 @@ public class CompositeTextProvider imple
      * @param key
      * @param args
      * @return
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText(String, String[])}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText(String, String[])}
      */
     public String getText(String key, String[] args) {
         return getText(key, key, args);
@@ -137,7 +137,7 @@ public class CompositeTextProvider imple
      * @param defaultValue
      * @param args
      * @return
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText#getText(String, String, java.util.List)}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText#getText(String, String, java.util.List)}
      */
     public String getText(String key, String defaultValue, List<?> args) {
         // if there's one text provider that gives us a msg not the same as defaultValue
@@ -161,7 +161,7 @@ public class CompositeTextProvider imple
      * @param defaultValue
      * @param args
      * @return
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText(String, String, String[])}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText(String, String, String[])}
      */
     public String getText(String key, String defaultValue, String[] args) {
         // if there's one text provider that gives us a msg not the same as defaultValue
@@ -186,7 +186,7 @@ public class CompositeTextProvider imple
      * @param args
      * @param stack
      * @return
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText(String, String, java.util.List, org.apache.struts2.xwork2.util.ValueStack)}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText(String, String, java.util.List, com.opensymphony.xwork2.util.ValueStack)}
      */
     public String getText(String key, String defaultValue, List<?> args, ValueStack stack) {
         // if there's one text provider that gives us a msg not the same as defaultValue
@@ -210,7 +210,7 @@ public class CompositeTextProvider imple
      * @param args
      * @param stack
      * @return
-     * @see {@link org.apache.struts2.xwork2.TextProvider#getText(String, String, String[], org.apache.struts2.xwork2.util.ValueStack)}
+     * @see {@link com.opensymphony.xwork2.TextProvider#getText(String, String, String[], com.opensymphony.xwork2.util.ValueStack)}
      */
     public String getText(String key, String defaultValue, String[] args, ValueStack stack) {
         // if there's one text provider that gives us a msg not the same as defaultValue
@@ -246,7 +246,7 @@ public class CompositeTextProvider imple
     }
 
     /**
      * It will consult each {@link org.apache.struts2.xwork2.TextProvider}s and return the first non-null {@link ResourceBundle}.
      *
      * @return
      * @see {@link TextProvider#getTexts()}
@@ -246,7 +246,7 @@ public class CompositeTextProvider imple
 
     /**
-     * It will consult each {@link org.apache.struts2.xwork2.TextProvider}s and return the first non-null {@link ResourceBundle}.
+     * It will consult each {@link com.opensymphony.xwork2.TextProvider}s and return the first non-null {@link ResourceBundle}.
      *
      * @return

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionInvocation.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionInvocation.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionProxyFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultActionProxyFactory.java Fri Dec  2 11:24:48 2011
@@ -13,16 +13,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.inject.Container;
-import org.apache.struts2.xwork2.inject.Inject;
+import com.opensymphony.xwork2.inject.Container;
+import com.opensymphony.xwork2.inject.Inject;
 
 import java.util.Map;
 
 
 /**
  * Default factory for {@link org.apache.struts2.xwork2.ActionProxyFactory}.
  *
  * @author Jason Carreira
  */
@@ -13,16 +13,16 @@
 
 /**
- * Default factory for {@link org.apache.struts2.xwork2.ActionProxyFactory}.
+ * Default factory for {@link com.opensymphony.xwork2.ActionProxyFactory}.
  *
  * @author Jason Carreira

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultTextProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/DefaultTextProvider.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProvider.java Fri Dec  2 11:24:48 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2;
+package com.opensymphony.xwork2;
 
-import org.apache.struts2.xwork2.util.ValueStack;
+import com.opensymphony.xwork2.util.ValueStack;
 
 import java.util.List;
 import java.util.ResourceBundle;
@@ -43,7 +43,7 @@ import java.util.ResourceBundle;
  * into it all framework messages)
  * &lt;constant name=&quot;system&quot; value=&quot;myTextProvider&quot; /&gt;
  * <p/>
  * Take a look on {@link org.apache.struts2.xwork2.ActionSupport} for example TextProvider implemntation.
  *
  * @author Jason Carreira
  * @author Rainer Hermanns
@@ -43,7 +43,7 @@ import java.util.ResourceBundle;
  * &lt;constant name=&quot;system&quot; value=&quot;myTextProvider&quot; /&gt;
  * <p/>
- * Take a look on {@link org.apache.struts2.xwork2.ActionSupport} for example TextProvider implemntation.
+ * Take a look on {@link com.opensymphony.xwork2.ActionSupport} for example TextProvider implemntation.
  *
  * @author Jason Carreira

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProviderFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/TextProviderFactory.java?rev=1209415&r1=1209414&r2=1209415&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/Parameterizable.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/entities/Parameterizable.java Fri Dec  2 11:24:48 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts2.xwork2.config.entities;
+package com.opensymphony.xwork2.config.entities;
 
 import java.util.Map;
 
@@ -23,7 +23,7 @@ import java.util.Map;
  * Actions implementing Parameterizable will receive a map of the static parameters defined in the action
  * configuration.
  * <p/>
  * <p/> The {@link org.apache.struts2.xwork2.interceptor.StaticParametersInterceptor} must be in the action's interceptor
  * queue for this to work.
  * <p/>
  * <!-- END SNIPPET: javadoc -->
@@ -23,7 +23,7 @@ import java.util.Map;
  * configuration.
  * <p/>
- * <p/> The {@link org.apache.struts2.xwork2.interceptor.StaticParametersInterceptor} must be in the action's interceptor
+ * <p/> The {@link com.opensymphony.xwork2.interceptor.StaticParametersInterceptor} must be in the action's interceptor
  * queue for this to work.
  * <p/>